Authors
==========
This package is being developed and maintained by `Fraunhofer AICOS <https://www.aicos.fraunhofer.pt/en/home.html>`_.

.. image:: imgs/fhp_logo.png
    :align: center
    :scale: 25 %
    :alt: FhP-AICOS

TSSEARCH was written in collaboration with `Cognitive Systems Lab of University of Bremen <https://www.uni-bremen.de/csl/>`_.

Lead Development Team
---------------------

- Duarte Folgado (`duarte.folgado@fraunhofer.pt <duarte.folgado@fraunhofer.pt>`_)
- Hugo Gamboa (`hugo.gamboa@fraunhofer.pt <hugo.gamboa@fraunhofer.pt>`_)
- Marília Barandas  (`marilia.barandas@fraunhofer.pt <marilia.barandas@fraunhofer.pt>`_)
- Maria Lua Nunes (`maria.nunes@fraunhofer.pt <maria.nunes@fraunhofer.pt>`_)
- Margarida Antunes (`maria.antunes@fraunhofer.pt <maria.antunes@fraunhofer.pt>`_)


Contributors
------------
- Hui Liu
- Tanja Schultz
- Yale Hartmann
